# colorprints v1.2

There are both very simple commands and a more complex RGB command

---

## These Commands all take in a basic string and print it out in color

printred(string)

printblue(string)

printgreen(string)

printyellow(string)

printorange(string)

printpurple(string)

printcyan(string)

printgrey(string)

---

## This Function will intake 3 RGB (0-255) Color Values and a string value
printRGB(int,int,int,String)
